use crate::prelude::*;

/// Gets the master password and deletes the account.
/// Although it doesn't use the master password, we get it to be sure that it's the user who used that command
async fn get_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    dialogue: MainDialogue,
    name: String,
    _: String,
) -> crate::Result<()> {
    dialogue.exit().await?;
    let user_id = msg.from().ok_or(NoUserInfo)?.id.0;
    Account::delete_by_id((user_id, name)).exec(&db).await?;
    bot.send_message(msg.chat.id, "The account is successfully deleted")
        .reply_markup(deletion_markup())
        .await?;
    Ok(())
}

handler!(
    get_account_name(name: String),
    "Send master password. Once you send correct master password the account is unrecoverable",
    State::GetMasterPass,
    get_master_pass
);

/// Handles /delete command
pub async fn delete(
    bot: Throttle<Bot>,
    msg: Message,
    dialogue: MainDialogue,
    db: DatabaseConnection,
) -> crate::Result<()> {
    let user_id = msg.from().ok_or(NoUserInfo)?.id.0;
    let markup = account_markup(user_id, &db).await?;
    if markup.keyboard.is_empty() {
        bot.send_message(msg.chat.id, "No accounts found")
            .reply_markup(deletion_markup())
            .await?;
        return Ok(());
    }
    let previous = bot
        .send_message(msg.chat.id, "Send the name of the account to delete")
        .reply_markup(markup)
        .await?;
    dialogue
        .update(State::GetExistingName(Handler::new(
            get_account_name,
            &previous,
        )))
        .await?;
    Ok(())
}
